==> ptrlib-1.3.5-py3-none-any.whl: ptrlib/pwn/sock.py <==
# coding: utf-8
from logging import getLogger
from ptrlib.util.encoding import *
from ptrlib.pwn.tube import *
import socket

logger = getLogger(__name__)


class Socket(Tube):
    def __init__(self, host, port=None, timeout=None):
        """Create a socket

        Create a new socket and establish a connection to the host.

        Args:
            host (str): The host name or ip address of the server
            port (int): The port number

        Returns:
            Socket: ``Socket`` instance.
        """
        super().__init__()

        if isinstance(host, bytes):
            host = bytes2str(host)

        if port is None:
            host = host.strip()
            if host.startswith('nc '):
                _, a, b = host.split()
                host, port = a, int(b)
            elif host.count(':') == 1:
                a, b = host.split(':')
                host, port = a, int(b)
            elif host.count(' ') == 1:
                a, b = host.split()
                host, port = a, int(b)
            else:
                raise ValueError("Specify port number")

        self.host = host
        self.port = port
        self.timeout = timeout
        # Create a new socket
        self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        # Establish a connection
        try:
            self.sock.connect((self.host, self.port))
            logger.info("Successfully connected to {0}:{1}".format(self.host, self.port))
        except ConnectionRefusedError as e:
            err = "Connection to {0}:{1} refused".format(self.host, self.port)
            logger.warning(err)
            raise e

    def _settimeout(self, timeout):
        if timeout is None:
            self.sock.settimeout(self.timeout)
        else:
            self.sock.settimeout(timeout)

    def _socket(self):
        return self.sock

    def _recv(self, size=4096, timeout=None):
        """Receive raw data

        Receive raw data of maximum `size` bytes length through the socket.

        Args:
            size    (int): The data size to receive
            timeout (int): Timeout (in second)

        Returns:
            bytes: The received data
        """
        self._settimeout(timeout)
        if size <= 0:
            logger.error("`size` must be larger than 0")
            return None
        
        try:
            data = self.sock.recv(size)
        except socket.timeout:
            raise TimeoutError("recv timeout")
        
        # No data received
        if len(data) == 0:
            data = None
        return data

    def send(self, data, timeout=None):
        """Send raw data

        Send raw data through the socket

        Args:
            data (bytes) : Data to send
            timeout (int): Timeout (in second)
        """
        self._settimeout(timeout)
        if isinstance(data, str):
            data = str2bytes(data)

        try:
            self.sock.send(data)
        except BrokenPipeError:
            logger.warning("Broken pipe")

    def close(self):
        """Close the socket

        Close the socket.
        This method is called from the destructor.
        """
        if self.sock:
            self.sock.close()
            self.sock = None
            logger.info("Connection to {0}:{1} closed".format(self.host, self.port))

    def shutdown(self, target):
        """Kill one connection

        Close send/recv socket.

        Args:
            target (str): Connection to close (`send` or `recv`)
        """
        if target in ['write', 'send', 'stdin']:
            self.sock.shutdown(socket.SHUT_WR)

        elif target in ['read', 'recv', 'stdout', 'stderr']:
            self.sock.shutdown(socket.SHUT_RD)

        else:
            logger.error("You must specify `send` or `recv` as target.")

    def __del__(self):
        self.close()

# alias
remote = Socket

==> ptrlib-1.3.8-py3-none-any.whl: ptrlib/pwn/sock.py <==
# coding: utf-8
from logging import getLogger
from ptrlib.util.encoding import *
from ptrlib.pwn.tube import *
import socket

logger = getLogger(__name__)


class Socket(Tube):
    def __init__(self, host, port=None, timeout=None):
        """Create a socket

        Create a new socket and establish a connection to the host.

        Args:
            host (str): The host name or ip address of the server
            port (int): The port number

        Returns:
            Socket: ``Socket`` instance.
        """
        super().__init__()

        if isinstance(host, bytes):
            host = bytes2str(host)

        if port is None:
            host = host.strip()
            if host.startswith('nc '):
                _, a, b = host.split()
                host, port = a, int(b)
            elif host.count(':') == 1:
                a, b = host.split(':')
                host, port = a, int(b)
            elif host.count(' ') == 1:
                a, b = host.split()
                host, port = a, int(b)
            else:
                raise ValueError("Specify port number")

        self.host = host
        self.port = port
        self.timeout = timeout
        # Create a new socket
        self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        # Establish a connection
        try:
            self.sock.connect((self.host, self.port))
            logger.info("Successfully connected to {0}:{1}".format(self.host, self.port))
        except ConnectionRefusedError as e:
            err = "Connection to {0}:{1} refused".format(self.host, self.port)
            logger.warning(err)
            raise e

    def _settimeout(self, timeout):
        if timeout is None:
            self.sock.settimeout(self.timeout)
        elif timeout > 0:
            self.sock.settimeout(timeout)

    def _socket(self):
        return self.sock

    def _recv(self, size=4096, timeout=None):
        """Receive raw data

        Receive raw data of maximum `size` bytes length through the socket.

        Args:
            size    (int): The data size to receive
            timeout (int): Timeout (in second)

        Returns:
            bytes: The received data
        """
        self._settimeout(timeout)
        if size <= 0:
            logger.error("`size` must be larger than 0")
            return None

        try:
            data = self.sock.recv(size)
        except socket.timeout:
            raise TimeoutError("Receive timeout")
        except ConnectionAbortedError as e:
            logger.warning("Connection aborted by the host")
            raise e

        # No data received
        if len(data) == 0:
            data = None
        return data

    def send(self, data, timeout=None):
        """Send raw data

        Send raw data through the socket

        Args:
            data (bytes) : Data to send
            timeout (int): Timeout (in second)
        """
        self._settimeout(timeout)
        if isinstance(data, str):
            data = str2bytes(data)

        try:
            self.sock.send(data)
        except BrokenPipeError:
            logger.warning("Broken pipe")
        except ConnectionAbortedError as e:
            logger.warning("Connection aborted by the host")
            raise e

    def close(self):
        """Close the socket

        Close the socket.
        This method is called from the destructor.
        """
        if self.sock:
            self.sock.close()
            self.sock = None
            logger.info("Connection to {0}:{1} closed".format(self.host, self.port))

    def shutdown(self, target):
        """Kill one connection

        Close send/recv socket.

        Args:
            target (str): Connection to close (`send` or `recv`)
        """
        if target in ['write', 'send', 'stdin']:
            self.sock.shutdown(socket.SHUT_WR)

        elif target in ['read', 'recv', 'stdout', 'stderr']:
            self.sock.shutdown(socket.SHUT_RD)

        else:
            logger.error("You must specify `send` or `recv` as target.")

    def __del__(self):
        self.close()

# alias
remote = Socket
